// Simulation of the Clarida, Gali, Gertler model

var da pie r rstar tau x dy; 	   // DECLARATION OF THE ENDOGENOUS VARIABLES

varexo eps_a eps_tau;    // DECLARATION OF THE STRUCTURAL INNOVATIONS.

parameters phi beta kappa phi_x phi_pie alpha rho lambda; // DECLARATION OF THE PARAMETERS.

// Parameter Values  
beta    = 0.97;
phi_x   = .15;
phi_pie = 1.5;
alpha   = 0.8;
rho     = 0.9;
lambda  = 0.5;
phi     = 1;
theta   = 0.75;
kappa   = ((1-theta)*(1-beta*theta)*(1+phi))/(theta);

// DECLARATION OF THE (LINEAR) DSGE MODEL: 
model(linear);

    beta*pie(+1) + kappa*x = pie;                                      // Calvo Pricing Equation
    r - pie(+1)-rstar   = x(+1) - x;                                   // Intertemporal Equation
    alpha*r(-1)+(1-alpha)*phi_pie*pie + (1-alpha)*phi_x*x = r;       // Monetary Policy Rule
//    r=rstar+phi_pie*pie;
    rstar = da(+1) + (1-lambda)/(1+phi)*tau;                           // Definition of the Natural Rate
    da = rho*da(-1) + eps_a ;
    tau       = lambda*tau(-1) + eps_tau;
    dy = x - x(-1) + da - (tau-tau(-1))/(1+phi); 

end;

shocks;
var eps_a;
stderr .02;
var eps_tau;
stderr .02;
end;

stoch_simul(irf=7,nograph,periods=5000) ;
sim=oo_.endo_simul;
save data sim

return


fprintf(' infl = %5.3f, empl (gap) = %5.3f, r = %5.3f, rstar = %5.3f, a = %5.3f\n', ...
  pie_news(1),x_news(1),r_news(1),rstar_news(1),a_news(1));

return
tech=(a_eps_a);
//  inflation, employment, interest rate, natural rate, output, natural output

subplot(2,2,1)
tt=1:length(a_eps_a);
plot(tt,pie_eps_a)
title('inflation')
axis tight

subplot(2,2,2)
plot(tt,x_eps_a+tech,tt,tech,'*-')
legend('actual output','natural output')
axis tight

subplot(2,2,3)
plot(tt,r_eps_a,tt,rstar_eps_a,'*-')
title('interest rates')
axis tight

subplot(2,2,4)
plot(tt,x_eps_a)
title('employment (output gap)')
axis tight

